@@ -39,17 +39,27 @@ public:
 
 	AutoSaver(const ServerBuffer& buffer,
 	          const std::string& filename,
-	          unsigned int interval);
+	          unsigned int interval,
+		  const std::string& post_save_hook);
 	~AutoSaver();
 
 	signal_error_type error_event() const;
+
+	void save();
 protected:
 	bool on_timer();
 
+	void on_document_insert(DocumentInfo& info);
+	void on_document_remove(DocumentInfo& info);
+	void on_document_change();
+
 	const ServerBuffer& m_buffer;
 	std::string m_filename;
+	std::string m_post_save_hook;
 	sigc::connection m_conn_timer;
 	signal_error_type m_signal_error;
+
+	bool m_has_modification;
 };
 
 }
