@@ -24,17 +24,34 @@
 #include <stdexcept>
 #include <glibmm/main.h>
 #include <glibmm/miscutils.h>
+#include <glibmm/spawn.h>
 #include "autosaver.hpp"
 
 Sobby::AutoSaver::AutoSaver(const ServerBuffer& buffer,
                             const std::string& filename,
-                            unsigned int interval):
-	m_buffer(buffer), m_filename(filename)
+                            unsigned int interval,
+			    const std::string& post_save_hook):
+	m_buffer(buffer), m_filename(filename),
+	m_post_save_hook(post_save_hook), m_has_modification(true)
 {
-	m_conn_timer = Glib::signal_timeout().connect(
-		sigc::mem_fun(*this, &AutoSaver::on_timer),
-		interval * 1000
-	);
+	if(interval > 0)
+	{
+		m_conn_timer = Glib::signal_timeout().connect(
+			sigc::mem_fun(*this, &AutoSaver::on_timer),
+			interval * 1000
+		);
+	}
+
+	buffer.document_insert_event().connect(
+		sigc::mem_fun(*this, &AutoSaver::on_document_insert));
+	buffer.document_remove_event().connect(
+		sigc::mem_fun(*this, &AutoSaver::on_document_remove));
+
+	for(ServerBuffer::document_iterator iter = buffer.document_begin();
+	    iter != buffer.document_end(); ++ iter)
+	{
+		on_document_insert(*iter);
+	}
 }
 
 Sobby::AutoSaver::~AutoSaver()
@@ -42,12 +59,29 @@ Sobby::AutoSaver::~AutoSaver()
 	m_conn_timer.disconnect();
 }
 
+void Sobby::AutoSaver::on_document_insert(DocumentInfo& document)
+{
+	document.get_content().changed_event().connect(
+		sigc::mem_fun(*this, &AutoSaver::on_document_change));
+
+	m_has_modification = true;
+}
+
+void Sobby::AutoSaver::on_document_remove(DocumentInfo& document)
+{
+}
+
+void Sobby::AutoSaver::on_document_change()
+{
+	m_has_modification = true;
+}
+
 Sobby::AutoSaver::signal_error_type Sobby::AutoSaver::error_event() const
 {
 	return m_signal_error;
 }
 
-bool Sobby::AutoSaver::on_timer()
+void Sobby::AutoSaver::save()
 {
 	try
 	{
@@ -61,11 +95,30 @@ bool Sobby::AutoSaver::on_timer()
 			throw std::runtime_error(std::strerror(errno) );*/
 
 		m_buffer.serialise(m_filename);
+		m_has_modification = false;
+
+		if(!m_post_save_hook.empty())
+		{
+			std::vector<std::string> argv;
+			argv.push_back(m_post_save_hook);
+			argv.push_back(m_filename);
+
+			Glib::spawn_async(".", argv);
+		}
 	}
 	catch(std::exception& e)
 	{
 		m_signal_error.emit(e);
 	}
+	catch(Glib::Exception& e)
+	{
+		// TODO: Convert to locale?
+		m_signal_error.emit(std::runtime_error(e.what()));
+	}
+}
 
+bool Sobby::AutoSaver::on_timer()
+{
+	if(m_has_modification) save();
 	return true;
 }
